#!/bin/sh

for JAR in FR fr-FR fr-mac fr-unix fr-win; do
	rm -f $JAR.jar;
	pushd $JAR;
	zip -0 -D ../$JAR.jar `find . -not -name 'mozilla-anglais.diff' |\
		grep -v CVS -` >/dev/null;
	popd;
done
